StreamKit
=========

A simple, cross-platform SDK for pub-sub messaging in Python.

.. image:: https://img.shields.io/badge/license-Apache-blue.svg?style=flat
    :target: https://www.apache.org/licenses/LICENSE-2.0
    :alt: License

.. image:: https://img.shields.io/pypi/v/streamkit.svg?style=flat&color=blue
    :target: https://pypi.org/project/streamkit
    :alt: PyPI Version

.. image:: https://img.shields.io/pypi/pyversions/streamkit.svg?logo=python&logoColor=white&style=flat
    :target: https://pypi.org/project/streamkit
    :alt: Python Versions

.. image:: https://readthedocs.org/projects/streamkit/badge/?version=latest&style=flat
    :target: https://streamkit.readthedocs.io
    :alt: Documentation

.. image:: https://pepy.tech/badge/streamkit
    :target: https://pepy.tech/badge/streamkit
    :alt: Downloads

|


Documentation
-------------

Documentation for getting started, the API, and common recipes are available at
`streamkit.readthedocs.io <https://streamkit.readthedocs.io>`_.

|

Contributions
-------------

Contributions are welcome in the form of suggestions for additional features, pull requests with
new features or bug fixes, etc. If you find bugs or have questions, open an *Issue* here. If and
when the project grows, a code of conduct will be provided along side a more comprehensive set of
guidelines for contributing; until then, just be nice.
